@@ -1,5 +1,5 @@
 from typing import Any, Dict
-from fastapi import APIRouter, Request, Depends
+from fastapi import APIRouter, Request, Depends, HTTPException, Response, status
 from ormar import Model
 from fastapi_helpers.crud import BaseCrud
 from .Paginate import Pagination
@@ -7,11 +7,17 @@ from .Paginate import Pagination
 
 class DefaultModelRouter():
 
-    router = None
+    router: APIRouter
     crud: BaseCrud
     model: Model
+    headers: Dict
 
-    def __init__(self, model: Model, crud: BaseCrud) -> None:
+    def __init__(
+        self,
+        model: Model,
+        crud: BaseCrud,
+        headers: Dict = None
+    ) -> None:
         self.model = model
         self.crud = crud
         self.router = APIRouter()
@@ -20,10 +26,10 @@ class DefaultModelRouter():
         self.router.add_api_route("/", self.create, methods=["POST"])
         self.router.add_api_route("/{id}/", self.update, methods=["PUT"])
         self.router.add_api_route("/{id}/", self.delete, methods=["DELETE"])
-
+        self.headers = headers
 
     async def read_list(
-        self,  
+        self,
         *,
         request: Request,
         options: Pagination = Depends(),
@@ -31,23 +37,28 @@ class DefaultModelRouter():
         options.set_filters(**request.query_params._dict)
         r = await self.crud.get_list(options)
         return r
-    
+
     async def read(
         self,
         *,
         id: int,
     ):
-        return await self.crud.get(id=id)
+        m = await self.crud.get(id=id)
+        if(m is None):
+            raise HTTPException(404, {
+                "status": "not found"
+            }, self.headers)
+        return Response(m, status.HTTP_200_OK, self.headers, "")
 
     async def create(
         self,
         *,
         model_in: Dict,
     ) -> Any:
-
-        return await self.crud.create(
+        m = await self.crud.create(
             model_in
         )
+        return Response(m, status.HTTP_201_CREATED, self.headers, )
 
     async def update(
         self,
@@ -55,18 +66,33 @@ class DefaultModelRouter():
         id: int,
         model_in:  Dict,
     ):
-        return await self.crud.update(
+        m = await self.crud.update(
             id,
             model_in
         )
-    
+        if(m is None):
+            raise HTTPException(404, {
+                "status": "not found"
+            }, self.headers)
+        return Response(
+            m, status.HTTP_201_CREATED, self.headers
+        )
+
     async def delete(
         self,
         *,
         id: int,
     ):
-        return await self.crud.delete(
+        m = await self.crud.delete(
             id=id,
         )
-
-    
\ No newline at end of file
+        if(m is None):
+            raise HTTPException(
+                404, {
+                    "status": "not found"
+                }, 
+                self.headers
+            )
+        return Response(
+            m, status.HTTP_202_ACCEPTED, self.headers
+        )
