@@ -1,18 +1,24 @@
+from types import MethodWrapperType
 from sqlalchemy.pool import NullPool
 from fastapi_helpers.db import DbConfig
 from fastapi_helpers.logging import DefaultLogger
 
+
 class Worker:
 
     db_config: DbConfig
     logger: DefaultLogger
 
-    def __init__(self, db_config:DbConfig, logger: DefaultLogger) -> None:
+    def __init__(
+        self,
+        db_config: DbConfig,
+        logger: DefaultLogger
+    ) -> None:
         self.db_config = db_config
-        self.logger  = logger
+        self.logger = logger
 
-    def use_db_connection(self, func):
-        '''Decorator that reports the execution time.'''
+    def use_db_connection(self, func) -> MethodWrapperType:
+        '''Decorator that connects to the db.'''
 
         async def wrap(*args, **kwargs):
             await self.db_config.connect_db(NullPool)
